/*
 * AutoDAO - Generic DAO on steroids implementation for Java.
 *
 * Copyright 2008-2010  Marat Radchenko <slonopotamus@users.sourceforge.net>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.autodao;

import org.jetbrains.annotations.NotNull;

/**
 * Pluggable mechanism for query argument transformation.
 * <p/>
 * See <a href="http://autodao.sourceforge.net/guide.html#Custom_query_argument_transformation">Custom query argument
 * transformation</a> for usage.
 * @param <F> input argument type this transformer can process.
 * @param <T> output argument type this transformer produces.
 * @since AutoDAO 0.6
 */
public interface QueryArgumentTransformer<F, T> {
  /**
   * Performs query argument transformation.
   * @param argument initial argument that was passed to DAO.
   * @return transformed argument that'll be passed to underlying ORM.
   */
  @NotNull
  T transform(@NotNull F argument);

  /** @return output argument type this transformer produces. */
  @NotNull
  Class<T> getTargetType();
}
