/*
 * AutoDAO - Generic DAO on steroids implementation for Java.
 *
 * Copyright 2008-2010  Marat Radchenko <slonopotamus@users.sourceforge.net>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.autodao.impl.hibernate;

import org.springframework.beans.factory.support.BeanDefinitionBuilder;
import org.springframework.beans.factory.xml.AbstractSingleBeanDefinitionParser;
import org.springframework.beans.factory.xml.ParserContext;
import org.w3c.dom.Element;

/**
 * Processes <code>dao:hibernate</code> elements and builds Spring bean.
 * <p/>
 * Creates {@link HibernateDao} bean and wrap it with {@link HibernateDaoProxyFactoryBean} so that AutoDAO magic works.
 * <p/>
 * NOT FOR PUBLIC USE.
 */
public final class HibernateDaoBeanDefinitionParser extends AbstractSingleBeanDefinitionParser {

  /** {@inheritDoc} */
  @Override
  protected boolean shouldGenerateIdAsFallback() {
    return true;
  }

  /** {@inheritDoc} */
  @Override
  protected void doParse(final Element element, final ParserContext context, final BeanDefinitionBuilder builder) {
    ParserUtils.applyDaoParams(builder, element, element.getAttribute("interface"), element.getAttribute("entity"));
  }

  @Override
  protected Class getBeanClass(final Element element) {
    return HibernateDaoProxyFactoryBean.class;
  }
}
