/*
 * AutoDAO - Generic DAO on steroids implementation for Java.
 *
 * Copyright 2008-2010  Marat Radchenko <slonopotamus@users.sourceforge.net>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.autodao.impl.hibernate;

import org.springframework.beans.factory.support.BeanDefinitionBuilder;
import org.w3c.dom.Element;

/**
 * Helper functions for custom Spring namespace tag parsing.
 * <p/>
 * NOT FOR PUBLIC USE.
 */
final class ParserUtils {
  private static final String SESSION_FACTORY_ATTRIBUTE = "session-factory";
  private static final String TRANSACTION_MANAGER_ATTRIBUTE = "transaction-manager";

  private ParserUtils() {
  }

  static void applyDaoParams(final BeanDefinitionBuilder builder,
                             final Element element,
                             final String daoInterfaceName,
                             final String entityName) {
    final String sessionFactory;
    if (element.hasAttribute(SESSION_FACTORY_ATTRIBUTE)) {
      sessionFactory = element.getAttribute(SESSION_FACTORY_ATTRIBUTE);
    } else {
      sessionFactory = "sessionFactory";
    }
    final String transactionManager;
    if (element.hasAttribute(TRANSACTION_MANAGER_ATTRIBUTE)) {
      transactionManager = element.getAttribute(TRANSACTION_MANAGER_ATTRIBUTE);
    } else {
      transactionManager = "transactionManager";
    }
    builder
        .addPropertyValue("daoInterface", daoInterfaceName)
        .addPropertyReference("sessionFactory", sessionFactory)
        .addPropertyReference("transactionManager", transactionManager)
        .addPropertyValue("entityType", entityName);
  }
}
